
# tsf-meta -- A Python package for large scale time series forecasting with meta-learning 
`tsfmeta` is a Python package for time series forecasting with meta-learning. Its goal is to make meta-learning available for researchers and time series forecasting practitioners in a unified, easy-to-use framework. 


# Installation
```bash
pip install tsfmeta
```
# Resources
- [**Examples to use the package**](https://github.com/Shawn-nau/tsfmeta/examples/)

# Description
`tsfmeta` was created with foundations on existing libraries in the PyTorch eco-system, stream-lined neural network layer definitions, temporal snapshot generators for batching, and integrated benchmark datasets. Specifically, the library provides a metadata class that abstracts handling data initialization, data iterating, train-test splitting, and feature extracting, etc., a meta-learner class that provides multiple predefined neural network architectures for meta-learning, and a utility class that provides functions that help users to create meta-data with their datasets.


# Citing
If you use `tsfmeta` (including ideas proposed in the documentation, examples and tests) in your research please **make sure to cite it**.
- Ma, S., & Fildes, R. (2021). Retail sales forecasting with meta-learning. European Journal of Operational Research, 288(1), 111-128. doi:https://doi.org/10.1016/j.ejor.2020.05.038

